@@ -1,4 +1,4 @@
-package Dispatch::Notification;
+package App::OverWatch::Notification;
 # ABSTRACT: Notification object
 
 use strict;
@@ -26,11 +26,11 @@ __END__
 
 =head1 NAME
 
-Dispatch::Notification - Notification object
+App::OverWatch::Notification - Notification object
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 ATTRIBUTES
 
